AsyncDatabase class

An opened sqlite3 database with async methods.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() Future<void>
Closes this database and releases associated resources.
createCollation({required String name, required CollatingFunction function}) Future<void>
createFunction({required String functionName, required ScalarFunction function, AllowedArgumentCount argumentCount = const AllowedArgumentCount.any(), bool deterministic = false, bool directOnly = true}) Future<void>
Register a custom function we can invoke from sql
dispose() Future<void>
Closes this database and releases associated resources.
execute(String sql, [List<Object?> parameters = const []]) Future<void>
Executes the sql statement with the provided parameters and ignores the result.
getLastInsertRowId() Future<int>
Returns the row id of the last inserted row.
getUserVersion() Future<int>
Returns the application defined version of this database.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
select(String sql, [List<Object?> parameters = const []]) Future<ResultSet>
Prepares the sql select statement and runs it with the provided parameters.
setUserVersion(int value) Future<void>
Set the application defined version of this database.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

open(String filename, {String? vfs, OpenMode mode = OpenMode.readWriteCreate, bool uri = false, bool? mutex}) Future<AsyncDatabase>
Opens a database file.